@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * mesomery.cc 
+ * mesomery.cc
  *
  * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,6 +27,7 @@
 #include "mesomer.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
+#include <brackets.h>
 #include "molecule.h"
 #include "theme.h"
 #include "view.h"
@@ -56,7 +57,7 @@ Mesomery::~Mesomery ()
 	MesomeryArrow *arrow;
 	Document *pDoc = reinterpret_cast<Document *> (GetDocument ());
 	Operation *pOp = pDoc->GetCurrentOperation ();
-	while ((pObj = GetFirstChild (i))) {
+	while ((pObj = GetFirstChild (i))) {		
 		if (pObj->GetType () == MesomeryArrowType) {
 			arrow = reinterpret_cast<MesomeryArrow*> (pObj);
 			arrow->SetStartMesomer (NULL);
@@ -64,7 +65,7 @@ Mesomery::~Mesomery ()
 			arrow->SetParent (GetParent ());
 			if (pOp)
 				pOp->AddObject (arrow, 1);
-			
+
 		} else
 			delete pObj;
 	}
@@ -274,22 +275,26 @@ static void BuildConnectivity ( set<Object *> &Objects, Mesomer* pMesomer)
 bool Mesomery::Validate (bool split)
 {
 	map<string, Object*>::iterator i;
+	int other_children = 0;
 	Object *pObj = GetFirstChild (i);
-	while (pObj && pObj->GetType () != MesomerType)
+	while (pObj && pObj->GetType () != MesomerType) {
+		if (pObj->GetType () == BracketsType)
+			other_children++;
 		pObj = GetNextChild (i);
+	}
 	if (pObj == NULL)
 		return false;
 	set<Object *> Objects;
 	Objects.insert (pObj);
 	BuildConnectivity (Objects, reinterpret_cast<Mesomer *> (pObj));
-	while (Objects.size () < GetChildrenNumber ()) {
+	while (Objects.size () + other_children < GetChildrenNumber ()) {
 		if (!split)
 			return 2;
 		pObj = GetFirstChild (i);
 		while (pObj && (pObj->GetType () != MesomerType))
 			pObj = GetNextChild (i);
 		if (reinterpret_cast<Mesomer *> (pObj)->Validate ()) {
-			Mesomery *ms = new Mesomery (GetParent (), 
+			Mesomery *ms = new Mesomery (GetParent (),
 								reinterpret_cast<Mesomer *> (pObj));
 			Document *pDoc = reinterpret_cast<Document*> (GetDocument ());
 			Operation *pOp = pDoc->GetCurrentOperation ();
@@ -528,11 +533,6 @@ void Mesomery::Align ()
 	View *pView = pDoc->GetView ();
 	Theme *pTheme = pDoc->GetTheme ();
 	WidgetData  *pData = reinterpret_cast <WidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
-	/* Update the canvas if necessary */
-/*	GnomeCanvas* w = GNOME_CANVAS (((Document*) GetDocument ())->GetWidget ());
-	while (w->idle_id)
-		gtk_main_iteration();
-	gnome_canvas_update_now (w);*/
 	map<string, Object*>::iterator i;
 	Object *pObj = GetFirstChild (i);
 	Mesomer *pStart = NULL, *mes0, *mes;
@@ -744,7 +744,7 @@ void Mesomery::Align ()
 	pView->Update (this);
 }
 
-/* Transform2D is just here to inhibit rotation of retrosynthesis while we do not have 
+/* Transform2D is just here to inhibit rotation of retrosynthesis while we do not have
 real 2D alignment (only vertical at the moment */
 void Mesomery::Transform2D (G_GNUC_UNUSED Matrix2D& m, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
@@ -811,7 +811,7 @@ double Mesomery::GetYAlign ()
 	while (pObj) {
 		if (pObj->GetType () == MesomerType)
 			if ((new_y = pObj->GetYAlign ()) < y)
-				y = new_y;			
+				y = new_y;
 		pObj = GetNextChild (i);
 	}
 	return y;
