@@ -406,7 +406,7 @@ static GtkActionEntry entries[] = {
 		  { "Zoom", NULL, N_("_Zoom to...%"), "<control>M",
 			  N_("Open Zoom Dialog Box"), G_CALLBACK (on_zoom) },
   { "ToolsMenu", NULL, N_("_Tools"), NULL, NULL, NULL },
-	  { "ImportMol", NULL, N_("_Import molecule"), NULL,
+	  { "ImportMol", NULL, N_("_Import molecule..."), NULL,
 		  N_("Import a molecule either from InChI or SMILES"), G_CALLBACK (WindowPrivate::ImportMolecule) },
   { "WindowsMenu", NULL, N_("_Windows"), NULL, NULL, NULL },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
@@ -785,7 +785,7 @@ bool Window::VerifySaved ()
 	do {
 		gchar* str = g_strdup_printf (_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
 		gcugtk::Message *box = new gcugtk::Message (static_cast < gcugtk::Application * > (GetApplication ()),
-		                                            str, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, GetWindow ());
+		                                            str, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, GetWindow (), true);
 		gtk_dialog_add_button (GTK_DIALOG (box->GetWindow ()),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		res = box->Run ();
 		g_free (str);
